@@ -115,5 +115,5 @@ def fastPlot(file):
     plt.plot(array[:, 0], array[:, 1])
 
 
-def rool(values, min, max):
+def roll(values, min, max):
     return ((values+min) % max)-min
